# Description

These folders concern partial reproducibility of our results. Overall,
- Data are reproduced using pipelines in `workflow/`
- One-off scripts are focused on running `simulate_ibd` and `simulate_ibd_isweep`
- Some IPython notebooks for plotting and manipulating tabular data are given.
- Does not include any small terminal commands used like: `cut`, `head`, `>>`, etc. 
